$TITLE ('COS DCE Boot-mode Patchable Constants, version 01.13')
$PAGELENGTH(42)
;*****************************************************************************
; File -- patchcst.a51
; Purpose -- COS DCE 8051 boot code, patchable constants.  In this file are
;            defined and allocated various parameters which control operation
;            of the boot-mode software.  These parameters are copied from CODE
;            space, where they are allocated, to XDATA upon startup so that
;            they may be changed through simple data uploads.
;
;            ------------------------   --------------------------------------
; Authors -- Original code by ...       Adapted for Boot-mode by ...
;            ------------------------   --------------------------------------
;            Mr. Daniel B. Blackman     William I. Clement, Ph.D., President
;            P.O. Box 20627             Clement Engineering, Inc.
;            Oakland, CA  94620         1261 Dogwood Road
;            (510) 910-9047             Arnold, MD  21012-2220
;                                       (410) 518-6591
;            ------------------------   --------------------------------------
;
; Change History --
; 24Aug00   Code version v17088 accepted by WIC from DBB
; 15Sep00   WIC, version 01.00 delivered.
;*****************************************************************************

$SET (PATCHCST=1)
$INCLUDE(common.inc)

   CSEG  at  PATCHCST_SEG   ; This is where we place the patchable constants
                            ; in CODE space.  They will be copied from here
                            ; to a DIFFERENT address in XDATA by subroutine
                            ; 'COPY_PATCHABLE'.  The table 'patch_table'
                            ; (below) gives the starting address, destination
                            ; address, and number of bytes to copy to
                            ; facilitate this task.

patchable_CSEG:             ; beginning label (in CODE segment) of area to be
                            ; copied from CODE to XDATA upon initialization

;*****************************************************************************
;                          Flight Software version
;*****************************************************************************
FILL_TO_BOUNDARY   16, 0FFh
fsw_version   equ   0113h   ; version 01.13
cLFDSWVER:
   DB   LOW(fsw_version), HIGH(fsw_version)   ; Version number
;-----------------------------------------------------------------------------

;*****************************************************************************
;                       ADC Conversion delay multiples
;*****************************************************************************
cMUX_DELAY:
   DB   5                   ; Delay (multiples of 0.0105 msec) between setting
                            ;    the MUX and starting the ADC.
cADC_DELAY:
   DB   1                   ; Delay (multiples of 0.0105 msec) between start
                            ;    of ADC and reading the ADC value.
;-----------------------------------------------------------------------------

;*****************************************************************************
; 'HSTERR_TABLE' provides conversion from diagnostic to HST error.
; Entries are pointers to HST error parameter.  Null pointers are for
; diagnostics which are NOT HST errors.
; NOTE:  'cHSTERR_TABLE' is the CODE segment label for this table.
;    When this table is copied to XDATA, it is placed elsewhere and label
;    'HSTERR_TABLE' reflects that XDATA location.  It is the XDATA location
;    ('HSTERR_TABLE') which is referenced in the software.
;*****************************************************************************
null_ptr   equ   0

FILL_TO_BOUNDARY   16, 0FFh
cHSTERR_TABLE:
   DW   null_ptr,     PARAM2,   mLFMXFER,     PARAM2     ; 00..03
   DW    SERIALN,    SERIALN,    SERIALN,   null_ptr     ; 04..07
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 08..0B
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 0C..0F

   DW   null_ptr,       RS17,   null_ptr,    SERIALN     ; 10..13
   DW   null_ptr,   null_ptr,   null_ptr,   mLFCTIME     ; 14..17
   DW   null_ptr,   null_ptr,   null_ptr,   mLFCTIME     ; 18..1B
   DW   mLFCTIME,   null_ptr,   null_ptr,   mLFCTIME     ; 1C..1F

   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 20..23
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 24..27
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 28..2B
   DW   null_ptr,   null_ptr,   null_ptr,       RS17     ; 2C..2F

   DW   null_ptr,    mBADISR, mBADREGION,   null_ptr     ; 30..33
;-----------------------------------------------------------------------------

;*****************************************************************************
; 'CRC_REGIONS' is an array of 12-byte structures used to implement
; background CRC checking over multiple regions of memory.  The contents of
; each element of the array are as follows:
;    (1)  Starting address in memory (16 bits, big-endian)
;    (2)  Number of bytes to check (16 bits, big-endian)
;    (3)  Memory space (0=XDATA, 1=CODE) (8-bits)
;    (4)  Next region number (8-bits)
;    (5)  CRC for this region (16-bits)
;    (6)  Previous CRC for this region, if non-zero (16-bits)
;    (7)  Diagnostic to send if CRCs miscompare, if MSB=5Ah (16-bits)
; The first entry is region '0', CRC determined by LFDCRC command ('LFMCRC')
; NOTE:  The labels at the beginning and end of this code segment, 
;    'cCRC_REGIONS' and 'end_cCRC_REGIONS' define the maximum number
;    of regions allocated and, hence, allowed ('num_regions').
;    The software will check to ensure that no unauthorized region is
;    requested since this would lead to software 'scribbling' in memory.
; NOTE:  To halt background CRC calculations, merely make a region point to
;    a 'next region' beyond the allowable range (i.e. >= 'num_regions')
; NOTE:  The command 'DCE_LFDCRC' will populate Region 0 with data specific
;    to its assigned task and zero out the 'previous CRC' to prevent
;    diagnostic and/or HST error.  It will NOT change the 'next region'
;    specifier.  That is up to the operator to command such a change.
;    By default, the 'next region' is region 1.
; NOTE:  'cCRC_REGIONS' is the CODE segment label for this table.
;    When this table is copied to XDATA, it is placed elsewhere and label
;    'CRC_REGIONS' reflects that XDATA location.  It is the XDATA location
;    ('CRC_REGIONS') which is referenced in the software.
; CRCs for regions 1-10 for boot build v01.13 are ...
;    Address Range    CRC
;    =============    ======
;    0x0000-0x17FF    0xBBBB
;    0x1800-0x1FFF    0xBBBB
;    0x8000-0x8FFF    0x0FE1  ; assumes upper 32KB is all 0FFh
;    0x9000-0x9FFF    0x0FE1
;    0xA000-0xAFFF    0x0FE1
;    0xB000-0xBFFF    0x0FE1
;    0xC000-0xCFFF    0x0FE1
;    0xD000-0xDFFF    0x0FE1
;    0xE000-0xEFFF    0x0FE1
;    0xF000-0xFFFF    0x0FE1
;*****************************************************************************
FILL_TO_BOUNDARY   16, 0FFh
cCRC_REGIONS:

; Region 0 (used by LFDCRC for its CRC region) ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
cLFMCRC:                 ; CRC mnemonic LFMCRC
cLFMCRC00:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
cCRC_REGIONS_00:         ; label used for computing 'sz_regions'

; Region 1 (PROM) ...
   DW   00000h, 01800h   ; starting address, number of bytes
   DB   1, 2             ; 1=CODE space, next region
cLFMROM:                 ; CRC mnemonic LFMROM
cLFMCRC01:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 2 (rest of PROM) ...
   DW   01800h, 0800h    ; starting address, number of bytes
   DB   1, 3             ; 1=CODE space, next region
cLFMCRC02:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 3 ...
   DW   08000h, 01000h   ; starting address, number of bytes
   DB   0, 4             ; 0=XDATA space, next region
cLFMCRC03:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 4 ...
   DW   09000h, 01000h   ; starting address, number of bytes
   DB   0, 5             ; 0=XDATA space, next region
cLFMCRC04:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 5 ...
   DW   0A000h, 01000h   ; starting address, number of bytes
   DB   0, 6             ; 0=XDATA space, next region
cLFMCRC05:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 6 ...
   DW   0B000h, 01000h   ; starting address, number of bytes
   DB   0, 7             ; 0=XDATA space, next region
cLFMCRC06:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 7 ...
   DW   0C000h, 01000h   ; starting address, number of bytes
   DB   0, 8             ; 0=XDATA space, next region
cLFMCRC07:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 8 ...
   DW   0D000h, 01000h   ; starting address, number of bytes
   DB   0, 9             ; 0=XDATA space, next region
cLFMCRC08:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 9 ...
   DW   0E000h, 01000h   ; starting address, number of bytes
   DB   0, 10            ; 0=XDATA space, next region
cLFMCRC09:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 10 ...
   DW   0F000h, 01000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region
cLFMCRC10:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 11 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 255           ; 0=XDATA space, next region (invalid)
cLFMCRC11:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 12 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 255           ; 0=XDATA space, next region (invalid)
cLFMCRC12:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 13 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 255           ; 0=XDATA space, next region (invalid)
cLFMCRC13:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 14 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 255           ; 0=XDATA space, next region (invalid)
cLFMCRC14:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC
   
; Region 15 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 255           ; 0=XDATA space, next region (invalid)
cLFMCRC15:
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0032         ; Diagnostic:  Bad CRC

end_cCRC_REGIONS:

; The software uses 'num_regions' to limit the allowed values for the
; 'next region' parameter. 'sz_regions' is the number of bytes used by
; each entry in the above table ...
sz_regions    equ   (cCRC_REGIONS_00 - cCRC_REGIONS)
num_regions   equ   (end_cCRC_REGIONS - cCRC_REGIONS)/sz_regions
;-----------------------------------------------------------------------------

;*****************************************************************************
; The housekeeping script is composed of 4-byte entries.  The first byte is
; the script opcode and the last byte is the repetition count -- how many
; successive entities of the same type (same opcode) to collect and put
; into housekeeping (also at successive addresses).  The opcodes (first byte)
; are:
;        00h -- End of script
;        01h -- Read bytes from CODE space
;        02h -- Read bytes from XDATA space (or memory-mapped I/O)
;        03h -- Read bytes from DATA space
;        06h -- Read bytes from Analog I/O
;        07h -- Move housekeeping pointer to specified address
;        08h -- Skip 'N' bytes of housekeeping packet
;        09h -- Clear 'N' bytes of housekeeping packet
;        46h -- Read TDC 'A'
;        82h -- Read TDC 'B'
;
; Depending on script opcode, bytes 2 & 3 take on various meanings.  They are:
;     Opcode -- Bytes 2&3
;        01h -- 16-bit address (MSB first)
;        02h -- 16-bit address (MSB first)
;        03h -- 16-bit address (MSB first, ignored)
;        06h -- 8-bit MUX address, N/A
;        07h -- 16-bit address to which to move HKP pointer
;        08h -- N/A
;        09h -- N/A
;        46h -- 8-bit TDC MUX address, N/A
;        82h -- 8-bit TDC MUX address, N/A
;
; Byte 4 is always the repetition count.
;
; NOTE:  'chkp_script' is the CODE segment label for this table.
;    When this table is copied to XDATA, it is placed elsewhere and label
;    'hkp_script' reflects that XDATA location.  It is the XDATA location
;    ('hkp_script') which is referenced in the software.
;*****************************************************************************

; The housekeeping script for Boot mode is below.  It does not contain all
; operate mode housekeeping items -- only those required for boot.
; NOTE:  In Boot Mode, the housekeeping buffer is 3440h - 383Fh.  When the
;    buffer is transferred to the CS computer, its upper address is masked
;    with 1Fh so as to produce addresses in the range 1440h - 183Fh (same
;    address range as for Operate Mode).
FILL_TO_BOUNDARY   16, 0FFh
chkp_script:
   DB   op_jump,   HIGH(3640h),    LOW(3640h),     0 ; jump to address 3640h
   ;
   DB   op_xdata,  HIGH(mLFDERR),  LOW(mLFDERR),   8 ; LFDERR (8 bytes)
   DB   op_xdata,  HIGH(mLFDERRP), LOW(mLFDERRP), 16 ; LFDERRP (16 bytes)
   DB   op_jump,   HIGH(3664h),    LOW(3664h),     0 ; jump
   ;
   DB   op_xdata,  HIGH(RS17),     LOW(RS17),     28 ; LFDCBUF
   DB   op_xdata,  HIGH(mLFCTIME), LOW(mLFCTIME),  4 ; LFCTIME
   DB   op_jump,   HIGH(36BCh),    LOW(36BCh),     0 ; jump
   ;
   DB   op_TDC_A,  40h,  0,  2  ; LFGSHFAX, TDC_A MUX=40h
                                ; LFGSTRAX, TDC_A MUX=41h
   DB   op_TDC_B,  40h,  0,  2  ; LFGSHFBX, TDC_B MUX=40h
                                ; LFGSTRBX, TDC_B MUX=41h
   DB   op_a2d,    08h,  0,  4  ; LFTDVAA, MUX=08h (1)
                                ; LFTACT,  MUX=09h (1)
                                ; LFTHVFM, MUX=0Ah (1)
                                ; LFTHVPS, MUX=0Bh (1)
   DB   op_a2d,    0Dh,  0,  1  ; LFTIP,   MUX=0Dh
   DB   op_a2d,    11h,  0,  1  ; LFTDVAB, MUX=11h
   DB   op_a2d,    0Eh,  0,  2  ; LFTAMPA, MUX=0Eh (1)
                                ; LFTAMPB, MUX=0Fh (1)
   DB   op_a2d,    0Ch,  0,  1  ; LFTTDCA, MUX=0Ch
   DB   op_a2d,    10h,  0,  1  ; LFTTDCB, MUX=10h
   DB   op_a2d,    12h,  0,  4  ; LFTLVPC, MUX=12h (1)
                                ; LFTDCE,  MUX=13h (1)
                                ; LFTFAN,  MUX=14h (1)
                                ; LFVP5DC, MUX=15h (1)
   DB   op_jump,   HIGH(36D2h),   LOW(36D2h),    0  ; jump
   ;
   DB   op_a2d,    22h,  0,  6  ; LFHIMONA, MUX=22h (1)
                                ; LFHIMONB, MUX=23h (1)
                                ; LFHVMONA, MUX=24h (1)
                                ; LFHVMONB, MUX=25h (1)
                                ; LFHQANA,  MUX=26h (1)
                                ; LFHQANB,  MUX=27h (1)
   DB   op_TDC_A,  50h,  0,  1  ; LFVP15TA, TDC_A MUX=50h
   DB   op_TDC_B,  50h,  0,  1  ; LFVP15TB, TDC_B MUX=50h
   DB   op_TDC_A,  52h,  0,  1  ; LFVP5TA,  TDC_A MUX=52h
   DB   op_TDC_B,  52h,  0,  1  ; LFVP5TB,  TDC_B MUX=52h
   DB   op_TDC_A,  51h,  0,  1  ; LFVM15TA, TDC_A MUX=51h
   DB   op_TDC_B,  51h,  0,  1  ; LFVM15TB, TDC_B MUX=51h
   DB   op_TDC_A,  53h,  0,  1  ; LFVM5TA,  TDC_A MUX=53h
   DB   op_TDC_B,  53h,  0,  1  ; LFVM5TB,  TDC_A MUX=53h
   DB   op_a2d,    16h,  0,  2  ; LFVP15D,  MUX=16h (1)
                                ; LFVM15D,  MUX=17h (1)
   DB   op_a2d,    44h,  0,  2  ; LFHVSETA, MUX=44h (1)
                                ; LFHVSETB, MUX=45h (1)
   DB   op_xdata,  HIGH(mLFSBITS2), LOW(mLFSBITS2), 2  ; 'Status bits 2'
   DB   op_TDC_A,  46h,  0,  1  ; LFGUQTA,  TDC_A MUX=46h
   DB   op_TDC_B,  46h,  0,  1  ; LFGUQTB,  TDC_B MUX=46h
   DB   op_TDC_A,  42h,  0,  1  ; LFGBWKAX, TDC_A MUX=42h
   DB   op_TDC_B,  42h,  0,  1  ; LFGBWKBX, TDC_B MUX=42h
   DB   op_TDC_A,  43h,  0,  1  ; LFGEWKAX, TDC_A MUX=43h
   DB   op_TDC_B,  43h,  0,  1  ; LFGEWKBX, TDC_B MUX=43h
   DB   op_jump,   HIGH(36EEh),  LOW(36EEh),     0  ; jump
   ;
   DB   op_TDC_A,  45h,  0,  1  ; LFGLQTA,  TDC_A MUX=45h
   DB   op_TDC_B,  45h,  0,  1  ; LFGLQTB,  TDC_B MUX=45h
   DB   op_TDC_A,  47h,  0,  1  ; LFGTTAX,  TDC_A MUX=47h
   DB   op_TDC_B,  47h,  0,  1  ; LFGTTBX,  TDC_B MUX=47h
   DB   op_xdata,  HIGH(mLFSBITS0), LOW(mLFSBITS0), 2  ; 'Status bits 0'
   DB   op_xdata,  HIGH(mLFSBITS1), LOW(mLFSBITS1), 2  ; 'Status bits 1'
   DB   op_jump,   HIGH(36FCh),     LOW(36FCh),     0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFMROM),   LOW(mLFMROM),   2 ; LFMROM
   DB   op_xdata,  HIGH(mLFDSWVER), LOW(mLFDSWVER), 2  ; LFDSWVER
   DB   op_xdata,  HIGH(mLFCPKTL),  LOW(mLFCPKTL),  4  ; LFCPKT
   DB   op_xdata,  HIGH(mLFDLSTC),  LOW(mLFDLSTC),  1  ; LFDLSTC
   DB   op_jump,   HIGH(3706h),     LOW(3706h),     0  ; jump
   ;
   DB   op_TDC_A,  54h,  0,  1  ; LFGREFA,  TDC_A MUX=54h
   DB   op_TDC_B,  54h,  0,  1  ; LFGREFB,  TDC_B MUX=54h
   DB   op_xdata,  HIGH(tLFDDIAGS+0), LOW(tLFDDIAGS+0), 1  ; LFDDIAG0
   DB   op_xdata,  HIGH(tLFDDIAGS+2), LOW(tLFDDIAGS+2), 1  ; LFDDIAG1
   DB   op_jump,   HIGH(370Ch),       LOW(370Ch),       0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFDCMDX), LOW(mLFDCMDX), 2 ; LFDCMDX
   DB   op_jump,   HIGH(3710h),   LOW(3710h),     0 ; jump
   ;
   DB   op_a2d,    43h,  0,  1  ; LFVPMON,  MUX=43h
   DB   op_xdata,  HIGH(tLFDDIAGS+4), LOW(tLFDDIAGS+4), 1  ; LFDDIAG2
   DB   op_jump,   HIGH(3714h),       LOW(3714h),       0  ; jump
   ;
   DB   op_a2d,    42h,  0,  1  ; LFRACTAN, MUX=42h
   DB   op_a2d,    41h,  0,  1  ; LFRMTRAN, MUX=41h
   DB   op_a2d,    21h,  0,  1  ; LFRAXI,   MUX=21h
   DB   op_a2d,    40h,  0,  1  ; LFRAXAN,  MUX=40h
   DB   op_xdata,  HIGH(mLFDCMDR), LOW(mLFDCMDR), 2 ; LFDCMDR
   DB   op_xdata,  HIGH(mLFMCRC), LOW(mLFMCRC),   2 ; LFDCRC
   DB   op_jump,   HIGH(3726h),   LOW(3726h),     0 ; jump
   ;
   DB   op_a2d,    84h,  0,  2  ; LFHVMAXA, MUX=84h
                                                    ; LFHVMAXB, MUX=85h
   DB   op_jump,   HIGH(372Ah),   LOW(372Ah),    0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFSBITS3), LOW(mLFSBITS3), 2  ; 'Status bits 3'
   DB   op_xdata,  HIGH(mLFSBITS4), LOW(mLFSBITS4), 1  ; 'Status bits 4'
   DB   op_xdata,  HIGH(mLFSBITS5), LOW(mLFSBITS5), 1  ; 'Status bits 5'
   DB   op_jump,   HIGH(3730h),     LOW(3730h),     0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFDPERF), LOW(mLFDPERF), 2 ; LFDPERF
   DB   op_jump,   HIGH(3736h),   LOW(3736h),     0 ; jump
   ;
   DB   op_xdata,  HIGH(mLFDMEXTR), LOW(mLFDMEXTR), 1  ; LFDMEXTR
   DB   op_xdata,  HIGH(mLFDMDATA), LOW(mLFDMDATA), 1  ; LFDMDATA
   DB   op_xdata,  HIGH(mLFDMONS),  LOW(mLFDMONS),  8  ; LFDMONS
   DB   op_xdata,  HIGH(mLFDMADD),  LOW(mLFDMADD), 16  ; LFDMADD
   DB   op_TDC_A,  62h,  0,  2  ; LFGBWKAY, TDC_A MUX=62h
                                ; LFGEWKAY, TDC_A MUX=63h
   DB   op_TDC_B,  62h,  0,  2  ; LFGBWKBY, TDC_B MUX=62h
                                ; LFGEWKBY, TDC_B MUX=63h
   DB   op_jump,   HIGH(375Eh),     LOW(375Eh),     0  ; jump
   ;
   DB   op_TDC_A,  44h,  0,  1  ; LFGTTAY,  TDC_A MUX=44h
   DB   op_TDC_B,  44h,  0,  1  ; LFGTTBY,  TDC_B MUX=44h
   DB   op_TDC_A,  60h,  0,  2  ; LFGSHFAY, TDC_A MUX=60h
                                ; LFGSTRAY, TDC_A MUX=61h
   DB   op_TDC_B,  60h,  0,  2  ; LFGSHFBY, TDC_B MUX=60h
                                ; LFGSTRBY, TDC_B MUX=61h
   DB   op_jump,   HIGH(3776h),     LOW(3776h),     0  ; jump
   ;
   DB   op_xdata,  HIGH(tLFDDIAGS+6), LOW(tLFDDIAGS+6), 1 ; LFDDIAG3
   DB   op_xdata,  HIGH(tLFDDIAGS+8), LOW(tLFDDIAGS+8), 1 ; LFDDIAG4
   DB   op_jump,   HIGH(3780h),   LOW(3780h),    0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFDDIAGS), LOW(mLFDDIAGS), 64  ; LFDDIAGS
   DB   op_a2d,    80h,  0,  2  ; LFVP5DA,  MUX=80h
                                ; LFVP5DB,  MUX=81h
   DB   op_jump,   HIGH(37D4h),   LOW(37D4h),    0  ; jump
   ;
   ; Items added for version 01.06 ...
   ; 16 CRCs ...
   DB   op_xdata,  HIGH(mLFMCRC00), LOW(mLFMCRC00),  2
   DB   op_xdata,  HIGH(mLFMCRC01), LOW(mLFMCRC01),  2
   DB   op_xdata,  HIGH(mLFMCRC02), LOW(mLFMCRC02),  2
   DB   op_xdata,  HIGH(mLFMCRC03), LOW(mLFMCRC03),  2
   DB   op_xdata,  HIGH(mLFMCRC04), LOW(mLFMCRC04),  2
   DB   op_xdata,  HIGH(mLFMCRC05), LOW(mLFMCRC05),  2
   DB   op_xdata,  HIGH(mLFMCRC06), LOW(mLFMCRC06),  2
   DB   op_xdata,  HIGH(mLFMCRC07), LOW(mLFMCRC07),  2
   DB   op_xdata,  HIGH(mLFMCRC08), LOW(mLFMCRC08),  2
   DB   op_xdata,  HIGH(mLFMCRC09), LOW(mLFMCRC09),  2
   DB   op_xdata,  HIGH(mLFMCRC10), LOW(mLFMCRC10),  2
   DB   op_xdata,  HIGH(mLFMCRC11), LOW(mLFMCRC11),  2
   DB   op_xdata,  HIGH(mLFMCRC12), LOW(mLFMCRC12),  2
   DB   op_xdata,  HIGH(mLFMCRC13), LOW(mLFMCRC13),  2
   DB   op_xdata,  HIGH(mLFMCRC14), LOW(mLFMCRC14),  2
   DB   op_xdata,  HIGH(mLFMCRC15), LOW(mLFMCRC15),  2
   ;
   DB   op_data, 0, LOW(maxSP), 1  ; maximum stack pointer
   ;
   DB   op_xdata,  HIGH(mLFMXFER), LOW(mLFMXFER),  2  ; LFMXFER
   ; end of items added for version 01.06
   DB   op_jump,   HIGH(3830h),     LOW(3830h),      0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFDDETID), LOW(mLFDDETID),  1  ; LFDDETID
   ;
   ; The rest is blank -- leave it so.
   ;
   DB   op_end,    0,0,0 ; end of script

   ; Save room for future growth of the script ...
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
;-----------------------------------------------------------------------------

end_patchable_CSEG:         ; ending label (in CODE segment) of area to be
                            ; copied from CODE to XDATA upon initialization

; The above patchable constants will be copied to XDATA beginning at address
; 'PC04' (see common.inc).

;*****************************************************************************
; 'patch_table' is a list of all blocks of patchable constants which are to be
; copied from CODE to XDATA.  Each entry is composed of 3 words:
; (1)  CODE segment block starting address
; (2)  XDATA destination address
; (3)  Number of bytes to copy
; If the number of bytes is zero, that indicates the end of 'patch_table'.
;*****************************************************************************
FILL_TO_BOUNDARY   16, 0FFh
patch_table:
   DW   patchable_CSEG, PC04, end_patchable_CSEG-patchable_CSEG
   DW   0, 0, 0   ; end of patch_table
;-----------------------------------------------------------------------------

;*****************************************************************************
; Those patchable constants which are referred to BY NAME in the software
; must have their XDATA address specified as an equate.  Since they reside
; in the CODE segment beginning at address 'patchable_CSEG' and in XDATA
; beginning at address 'PC04', we merely add to the CODE segment address the
; difference between these two offsets to find the XDATA address.
;*****************************************************************************
delta          equ   (PC04-patchable_CSEG)    ; amount to add to each ...
mLFDSWVER      equ   cLFDSWVER     + delta
mMUX_DELAY     equ   cMUX_DELAY    + delta
mADC_DELAY     equ   cADC_DELAY    + delta
mLFMCRC        equ   cLFMCRC       + delta
mLFMROM        equ   cLFMROM       + delta
mLFMCRC00      equ   cLFMCRC00     + delta
mLFMCRC01      equ   cLFMCRC01     + delta
mLFMCRC02      equ   cLFMCRC02     + delta
mLFMCRC03      equ   cLFMCRC03     + delta
mLFMCRC04      equ   cLFMCRC04     + delta
mLFMCRC05      equ   cLFMCRC05     + delta
mLFMCRC06      equ   cLFMCRC06     + delta
mLFMCRC07      equ   cLFMCRC07     + delta
mLFMCRC08      equ   cLFMCRC08     + delta
mLFMCRC09      equ   cLFMCRC09     + delta
mLFMCRC10      equ   cLFMCRC10     + delta
mLFMCRC11      equ   cLFMCRC11     + delta
mLFMCRC12      equ   cLFMCRC12     + delta
mLFMCRC13      equ   cLFMCRC13     + delta
mLFMCRC14      equ   cLFMCRC14     + delta
mLFMCRC15      equ   cLFMCRC15     + delta
HSTERR_TABLE   equ   cHSTERR_TABLE + delta
CRC_REGIONS    equ   cCRC_REGIONS  + delta
hkp_script     equ   chkp_script   + delta
;-----------------------------------------------------------------------------

;*****************************************************************************
; In order to prevent accidentally overlapping XDATA memory usage, we will
; block out an area of XDATA of the same size as the patchable constants to
; be copied (and at the same addresses, of course).  Additionally, space for
; the upload buffer, download buffer, command buffer, and housekeeping buffer
; is reserved.  This approach allows the linker to warn us if another XDATA
; allocation overlaps any of these areas.
;*****************************************************************************
   XSEG  at  RS01              ; reserve 1024 bytes for upload buffer
xRS01:   DS  1024

   XSEG  at  RS17              ; reserve 28 bytes for command packet
xRS17:   DS  28

   XSEG  at  TS01              ; reserve 1024 bytes for download buffer
xTS01:   DS  1024

   XSEG  at  TS17              ; reserve 1024 bytes for housekeeping buffer
xTS17:   DS  1024

   XSEG  at  PC04              ; reserve the patchable constants space
xPATCH:  DS  end_patchable_CSEG-patchable_CSEG
;-----------------------------------------------------------------------------

;*****************************************************************************
; Working copies of items which will go into the housekeeping packet are
; allocated here.  Subroutine 'BUILD_HKP' constructs the housekeeping
; packet from information herein and elsewhere.  Where possible, blocks of
; items here are layed out in the same order (within the block) as the
; expected order in housekeeping, in order to simplify and speed-up the
; copy-to-housekeeping which is performed in 'BUILD_HKP'.
;*****************************************************************************
   XSEG   at   PC00

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; KEEP IN THIS ORDER ...
mTICKS:      DS    1        ; counts 20 msec intervals (1/50 second)
mLFCTIME:    DS    4        ; seconds counter
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; Various others (need not be kept in order) ...

; Diagnostics and HST errors ...
mLFDDIAGS:   DS   64        ; Push-down stack of last 32 diagnostic msgs.
mDIAG_NUM:   DS    1        ; counter of total number of diagnostics
mLFDERR:     DS    8        ; 8 HST error locations
mLFDERRP:    DS   16        ; 8 HST error parameters

; Create an array which holds up to 5 diagnostics stored since the last
; housekeeping packet was sent ...
tLFDDIAGS    equ   $        ; assembler need a little help with its math
                            ; so create this 'equate' at the same address as
                            ; 'mCURR_5'
mCURR_5:     DS   10        ; current (this 1-second) 5 diagnostics w/ serial
mCURR_NUM:   DS    1        ; number of diagnostics in 'mCURR_5' list

; Various ...
mLFCPKTL:    DS    4        ; packet counter (long word)
mLFDCMDR:    DS    2        ; commands received counter
mLFDCMDX:    DS    2        ; commands executed counter
mLFDPERF:    DS    2        ; DCE Performance monitor.  Exec. loop counter.
mLFMXFER:    DS    2        ; upload/download packet CRC
mLFDLSTC:    DS    1        ; last DCE Op-code executed
mCWNS:       DS    2        ; counts commands words received but not stored
mWNS:        DS    4        ; command long word received but not stored
mLFDDETID:   DS    1        ; Detector ID bits (concat LFDDETID1:LFDDETID1)
mBADISR:     DS    2        ; 2 bytes for diagnostic 31h
mBADREGION:  DS    2        ; 2-byte parameter for HST error for bad CRC

; Memory Monitor parameters ...
mLFDMEXTR:   DS    1        ; external/internal select bits
mLFDMDATA:   DS    1        ; data/code select bits
mLFDMONS:    DS    8        ; data values
mLFDMADD:    DS   16        ; addresses

; 6 status words (first 4 are 16-bits each, last 2 are 8-bits each) ...
mLFSBITS0:   DS    2
mLFSBITS1:   DS    2
mLFSBITS2:   DS    2
mLFSBITS3:   DS    2
mLFSBITS4:   DS    1
mLFSBITS5:   DS    1

             DS    PC04-$   ; Block out the rest of the space up to where
                            ; the patchable constants begin (address 'PC04').
;-----------------------------------------------------------------------------

;*****************************************************************************
;                      Reset pattern (6 bytes) at 3FFAh
;*****************************************************************************
   XSEG   at   3FFAh
mPATTERN:    DS    6        ; 6-byte pattern -- watchdog vs. power-on reset
;-----------------------------------------------------------------------------

END                         ; patchcst.a51








